Component

Struct Component 

pub struct Component { /* private fields */ }
A Component in an ICE Stream

Implementations

Source

impl Component

pub fn id(&self) -> usize

The component identifier within a particular ICE Stream

pub fn stream(&self) -> Stream

Retrieve the Stream for this component.

pub fn state(&self) -> ComponentConnectionState

Retrieve the current state of a Component

pub fn selected_pair(&self) -> Option<CandidatePair>

The CandidatePair this component has selected to send/receive data with. This will not be valid until the Component has reached ComponentConnectionState::Connected

pub fn gather_candidates<'a, 'b>( &self, sockets: impl IntoIterator<Item = (TransportType, &'a Address)>, turn_servers: impl IntoIterator<Item = (&'b Address, TurnConfig)>, ) -> Result<(), AgentError>

Start gathering candidates for this component. The parent Agent::poll is used to progress the gathering.

Candidates will be generated as follows (if they succeed):

  1. A host candidate for each sockets[i]. If TCP, then both an active and passive host candidate will be generated.
  2. For each configured STUN server a reflexive candidate if different from any other candidate produced. The local address for each STUN server connection will be one of the entries provided in sockets.
  3. For each turn_servers[i] a TURN allocation will be attempted and a relayed candidate produced on success. If you would like multiple options for relayed candidates, e.g. UDP, TCP, TCP/TLS, then provide each options as different entries in the provided Iterator. The Address for each TURN server is the local address to communicate with the TURN server and should be different than any value provided through sockets.
pub fn set_selected_pair(&self, pair: CandidatePair) -> Result<(), AgentError>

Set the pair that will be used to send/receive data. This will override the ICE negotiation chosen value.

pub fn send( &self, data: &[u8], now: Instant, ) -> Result<AgentTransmit, AgentError>

Send data to the peer using the selected pair. This will not succeed until the Component has reached ComponentConnectionState::Connected